@@ -21,14 +21,16 @@ def get_element_by_xpath(xsd_tree, xpath, namespaces=None):
         default_prefix = get_default_prefix(namespaces)
 
         # Transform xpath into LXML format
-        xpath = xpath.replace(default_prefix + ":", xml_utils_constants.LXML_SCHEMA_NAMESPACE)
+        xpath = xpath.replace(
+            default_prefix + ":", xml_utils_constants.LXML_SCHEMA_NAMESPACE
+        )
 
     try:
         element = xsd_tree.find(xpath)
     except:
-        raise XMLError('Unable to find an element for the given Xpath.')
+        raise XMLError("Unable to find an element for the given Xpath.")
 
     if element is not None:
         return element
     else:
-        raise XMLError('Unable to find an element for the given Xpath.')
+        raise XMLError("Unable to find an element for the given Xpath.")
